function jpf2_mdsplus_data_processor_2014a

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input: none explicit, takes in 2-column, n-row matrices of xy data in 
%order, sorted smallest to largest by x-value.
%
%Output: mdsplus_averages.txt - gives the average values of the y-values.
%Values are taken at 0.25 millisecond intervals over the specified x-grid
%
%this function is designed to take in a 2-column, n-row matrix of x-y data
%on an nonuniform grid of x-values, and calculate the average value of y.  
%It takes this input, and makes a linear interpolation between y-values at
%values present on the new x-grid.  It sums the values taken at each point, and
%divides them by the number of points on the new x-grid.
%
%example:
%x-y pair of data, separatred by column during the read process
%x-values=[1;1.5;3;3.5;4.1;4.9]
%y-values=[10;20;30;40;50;60]
%x-grid=[1;2;3;4]
%new x-y pairs [1,10;2,20;3,30;4,40.x]

%all getdata output text files (xy pairs), and timing files (inter-ELM 
%slice delimiters) must be in the same directory as this file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%these variables must be input for each run
shot_number='144981';
timeid='3050';
runid='j8d97';

%display and set name of file being opened for timing data
display 'the timing file being opened for this run is:'
timing_file=strcat(shot_number,'_',timeid,'_',runid,'_','timing.txt')

%read in the timing delimiters
interELM_delimiters=dlmread(timing_file);

%list out the names of the variable files to read in
varfilenames={'aux_power','btor','elongation','intcpt_rin','intcpt_rout'...
    ,'intcpt_zin','intcpt_zout','lineavg_density','major_radius',...
    'minor_radius','ohmic_power','plasma_current','q95','ssi95','taumhd'...
    ,'triangularity','xpoint_r','xpoint_z'};

%read in xy pairs to separate matrices, to avoid having to standardize
%length and for readability
%aux_power_xy=dlmread(strcat('aux_power','.txt'),'\t');
%btor_xy=dlmread(strcat('btor','.txt'),'\t');
%elongation_xy=dlmread(strcat('elongation','.txt'),'\t');
%intcpt_rin_xy=dlmread(strcat('intcpt_rin','.txt'),'\t');
%intcpt_rout_xy=dlmread(strcat('intcpt_rout','.txt'),'\t');
%intcpt_zin_xy=dlmread(strcat('intcpt_zin','.txt'),'\t');
%intcpt_zout_xy=dlmread(strcat('intcpt_zout','.txt'),'\t');
%lineavg_density_xy=dlmread(strcat('lineavg_density','.txt'),'\t');
%major_radius_xy=dlmread(strcat('major_radius','.txt'),'\t');
%minor_radius_xy=dlmread(strcat('minor_radius','.txt'),'\t');
%ohmic_power_xy=dlmread(strcat('ohmic_power','.txt'),'\t');
%plasma_current_xy=dlmread(strcat('plasma_current','.txt'),'\t');
%q95_xy=dlmread(strcat('q95','.txt'),'\t');
%ssi95_xy=dlmread(strcat('ssi95','.txt'),'\t');
%taumhd_xy=dlmread(strcat('taumhd','.txt'),'\t');
%triangularity_xy=dlmread(strcat('triangularity','.txt'),'\t');
%xpoint_r_xy=dlmread(strcat('xpoint_r','.txt'),'\t');
%xpoint_z_xy=dlmread(strcat('xpoint_z','.txt'),'\t');

%read xy pairs into cell array because of different lengths
for i=1:length(varfilenames)
    xy_array{i}=dlmread(strcat(varfilenames{i},'.txt'));
end
xy_array;
interELM_delimiters;

%outputs xy pairs to a text file
xy_pairs=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'xy_pairs.txt'),'w');
for i=1:length(varfilenames);
    fprintf(xy_pairs,'\r\n%s %s\r\n\r\n','rho',varfilenames{i});
    for j=1:length(xy_array{i});
        fprintf(xy_pairs,'%f %f\r\n',xy_array{i}(j,:));
    end
end
fclose(xy_pairs);

for i=1:length(varfilenames);
    varfilenames{i}
    deletion_counter=0;
    shifting_endpoint=length(xy_array{i});
    g=1;
    while g<=shifting_endpoint
        g;
        shifting_endpoint;
        if and(xy_array{i}(g,2)<0.0001,xy_array{i}(g,2)>-0.0001)
            xy_array{i}(g,:)=[];
            deletion_counter=deletion_counter+1;
            shifting_endpoint=shifting_endpoint-1;
        else
            zero_removed_xy_array{i}(g,:)=xy_array{i}(g,:);
        end
        g=g+1;
    end
    deletion_counter
end

zero_removed_xy_pairs=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'zero_removed_xy_pairs.txt'),'w');
for i=1:length(varfilenames);
    fprintf(zero_removed_xy_pairs,'\r\n%s %s\r\n\r\n','rho',varfilenames{i});
    for j=1:length(zero_removed_xy_array{i});
        fprintf(zero_removed_xy_pairs,'%f %f\r\n',zero_removed_xy_array{i}(j,:));
    end
end
fclose(zero_removed_xy_pairs);

%filter xy pairs so that only those within the timing window remain
for i=1:length(varfilenames)
    counter=0;
    for j=1:length(interELM_delimiters);
        for k=1:length(xy_array{i})
            if and(zero_removed_xy_array{i}(k,1)>=interELM_delimiters(j,1),...
                    zero_removed_xy_array{i}(k,1)<=interELM_delimiters(j,2))
                counter=counter+1;
                filtered_xy_array{i}(counter,1)=xy_array{i}(k,1);
                filtered_xy_array{i}(counter,2)=xy_array{i}(k,2);
            else end
        end
    end
end

%outputs filtered xy pairs to a text file
filtered_xy_pairs=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'filtered_xy_pairs.txt'),'w');
for i=1:length(varfilenames);
    fprintf(filtered_xy_pairs,'\r\n%s %s\r\n\r\n','rho',varfilenames{i});
    for j=1:length(filtered_xy_array{i});
        fprintf(filtered_xy_pairs,'%f %f\r\n',filtered_xy_array{i}(j,:));
    end
end
fclose(filtered_xy_pairs);

%create 0.25 millisecond grid within the interELM_delimiters
gridpoint_vector=[2000];
for i=1:length(interELM_delimiters);    
    beginning_gridpoint=(((round(interELM_delimiters(i,1)))*4)/4);
    if gridpoint_vector(1)==2000
        gridpoint_vector(1)=beginning_gridpoint;
    else end
    ending_gridpoint=(((round(interELM_delimiters(i,2)))*4)/4);
    index=beginning_gridpoint;
    while gridpoint_vector(end)<ending_gridpoint
        index=index+0.25;
        gridpoint_vector=[gridpoint_vector index];
    end
end

%outputs gridpoints to a text file
gridpoint_file=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'gridpoints.txt'),'w');
for i=1:length(gridpoint_vector);
    fprintf(gridpoint_file,'%f\r\n',gridpoint_vector(i));
end
fclose(filtered_xy_pairs);

for i=1:length(varfilenames);
    for j=1:length(gridpoint_vector)
        final_xy_array{i}(j,1)=gridpoint_vector(j);
        final_xy_array{i}(j,2)=interp1(xy_array{i}(:,1),xy_array{i}(:,2)...
            ,gridpoint_vector(j));
    end
end

%removed 3-6-14 to do grid and interpolation separately
%interpolate to 0.25 millisecond grid
%for i=1:length(varfilenames)
%    counter=0;
%    for j=length(interELM_delimiters);
%        beginning_grid_point=(((round(interELM_delimiters(j,1)))*4)/4);
%        ending_grid_point=(((round(interELM_delimiters(j,2)))*4)/4);
%        gridpoints=(ending_grid_point-beginning_grid_point)*4;
%        gridpoints_vector(gridpoints)=ending_grid_point;
%        for jj=0:length(gridpoints_vector)-1
%            gridpoints_vector(jj+1)=beginning_grid_point+0.25*jj;
%        end
%        for k=1:gridpoints
%            counter=counter+1
%            final_xy_array{i}(counter,2)=interp1(xy_array{i}(:,1),...
%                xy_array{i}(:,2),gridpoints_vector(k));
%            final_xy_array{i}(counter,1)=gridpoints_vector(k);
%        end
%        last_gridpoint
%    end
%    gridpoints_vector
%end

%output final xy pairs to a text file
final_xy_pairs=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'final_xy_pairs.txt'),'w');
for i=1:length(varfilenames);
    fprintf(final_xy_pairs,'%s %s\r\n','rho',varfilenames{i});
    for j=1:length(final_xy_array{i});
        fprintf(final_xy_pairs,'%f %f\r\n',final_xy_array{i}(j,:));
    end
end
fclose(final_xy_pairs);

%average values on the 0.25 millisecond grid
for i=1:length(varfilenames);
    avg_vector(i)=mean(final_xy_array{i}(:,2));
    output_array{1,1}=varfilenames;
    output_array{2,1}=avg_vector;
end

%output averages to a text file
avg_file=fopen(strcat(shot_number,'_',timeid,'_',runid,'_',...
    'averages.txt'),'w');
for i=1:length(varfilenames);
    fprintf(avg_file,'%s %s %1.2e\r\n',output_array{1}{i},'=',...
        output_array{2}(i));
end


end


    
